#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
#   unv2fistr.py
#
#       unv →　abaqus　→　fistr　の順にメッシュ変換
#
#       unv2fistr.py <unvファイル名>
#
#
#   15/03/19    新規作成
#      09/01    windows対応のため、os.sepに修正
#      10/27    unvファイルの行末修正（file内容チェック）を追加
#   16/06/15    ヘルプ表示を修正
#   17/09/26    高速化の為、fileCheck時の書き出し方法を修正
#   18/03/24    高速化の為、fileCheck方法を修正。
#      07/06    file名中に「.」があると、エラー停止する為、修正。（バグ修正）
#   19/01/08    python3用に書き換え
#      04/06    pythonスクリプト起動時にフルパスで指定する様に修正
#

import sys
import os
import glob
import pyFistr

binAppPath = pyFistr.binAppPath
pythonAppPath = pyFistr.pythonAppPath

#
#  printMsg
#
def printMsg():
    msg = """
<unv2fistr.py>
unvフォーマットのmeshをFrontISTR用mesh(HECMWフォーマット）に変換する。
この変換は、unv -> abaqus -> fistr の順番で変換している。

<使い方>
unv2fistr.py <unvファイル>

例：
unv2fistr.py name.unv
unv2fistr.py name
"""
    print (msg)

#
#  abaqus2fistr
#    abaqusをfistrに変換
def abaqus2fistr(fileName, newName):
    print
    print ("convert abaqus to fistr...")
    comm = "python3 " + binAppPath + "abaqus2fistr.py " + fileName
    print (comm)
    os.system(comm)

#
#  unv2abaqus
#    unvをabaqusに変換
def unv2abaqus(fileName, newName):
    print
    print ("convert unv to abaqus...")
    comm = "python3 " + binAppPath + "unv2abaqusEx.py " + fileName + " " + newName + " N"
    print (comm)
    os.system(comm)

#
#  checkUnvFile
#    unvFileの行末コードをチェック修正
def checkUnvFile(fileName):
    #500byte分読み込み
    f=open(fileName)
    cont = f.read(500)
    f.close()
    #osチェック
    if os.name == "nt":
        #windowsの場合
        lines = cont.split("\r\n")
        if len(lines) > 1:
            return
    else:
        #linuxの場合
        lines = cont.split("\r\n")
        if len(lines) == 1:
            lines = cont.split("\n")
            if len(lines) > 1:
                return
    #読み込み、書き込み（osと行末コードが合わない場合）
    f = open(fileName); lines = f.readlines(); f.close()
    w = open(fileName, "w")
    for line in lines:
        w.write(line)
    w.close()
    return


if __name__=='__main__':
    if len(sys.argv) == 1:
        printMsg()
        exit()

    name = sys.argv[1]
    if name[:len("-h")] == "-h" or name[:len("--help")] == "--help":
        printMsg()
    else:
        #file名を取得
        fileDir = os.sep.join(sys.argv[1].split(os.sep)[:-1])
        if fileDir == "":
            fileDir = os.getcwd()
        fileName = sys.argv[1].split(os.sep)[-1]
        if fileName[-4:] != ".unv":
            fileName += ".unv"
        #file有無チェック
        if len(glob.glob(fileDir+os.sep+fileName)) == 0:
            print()
            print ("error:「" + fileDir + os.sep + fileName + "」が存在しません。")
            exit()
        #file内容をチェック
        print ()
        print ("checking file contents...")
        checkUnvFile(fileDir+os.sep+fileName)
        #abaqusに変換
        #newName = fileName.split(".")[0]
        newName = ".".join(fileName.split(".")[:-1])
        unv2abaqus(fileDir+os.sep+fileName, fileDir+os.sep+newName)
        #fistrに変換
        abaqusName = newName + ".inp"
        fistrName = newName + ".msh"
        abaqus2fistr(fileDir+os.sep+abaqusName, fileDir+os.sep+fistrName)

