#!/usr/bin/python3  
# -*- coding: utf-8 -*-    
#
#       addPrincipalStress.py
#
#       データに主応力を追加する
#
#   使い方
#   addPrincipalStressWithDialog <detaFile名>
#       dataFile名   :wildCardで指定する
#                     currentDir内のfileを指定する（重要）
#
#   15/06/19    新規作成
#      09/01    windows対応として、os.sepに変更
#      09/02    "\n"→os.linesepに修正
#      12/18    windows版のpangoWarning対策実施
#               主ひずみ、misesひずみを追加
#      12/25    行末コードlsを修正
#   16/01/06    tresca応力、ひずみを追加
#      03/29    tensor名を変数に設定。
#   19/01/10    python3用に書き換え
#
#

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk

import sys
import os
import glob
import pyFistr


ls = "\n"
addFlag = ""
stressTensor = ""
strainTensor = ""

#
#  addNewItem
#    指定項目をvtkファイルに追加する
def addNewItems():
    files = glob.glob("convFistrModel.res*.vtk")
    if len(files) == 0:
        error = "noFile"
        return error

    #項目追加
    print()
    print (_(u"主応力を結果に追加します"))
    steps = []
    nameHeader = ".".join(files[0].split(".")[:-2])
    for fileName in files:
        name = fileName
        step = name.split(".")[-2]
        steps.append(int(step))
    steps.sort()
    names = []
    i = 0
    for fileName in files:
        name = nameHeader+ "." + str(steps[i]) + ".vtk"
        names.append(name)
        i += 1

    error = ""
    for fileName in names:
        name = fileName.split(os.sep)[-1]
        if len(glob.glob(fileName)) == 0:
            error = "noFile"
            break
        #vtkファイル読み込み
        f=open(fileName); lines=f.readlines(); f.close()
        messH = ""
        if (addFlag[0] == "1"):
            messH += _(u"mises応力 ")
        if ((addFlag[1] == "1") or (addFlag[2] == "1")):
            messH  += _(u"主応力 ")
        if (addFlag[6] == "1"):
            messH += _(u"tresca応力 ")
        if (addFlag[3] == "1"):
            messH += _(u"misesひずみ ")
        if ((addFlag[4] == "1") or (addFlag[5] == "1")):
            messH += _(u"主ひずみ ")
        if (addFlag[7] == "1"):
            messH += _(u"trescaひずみ ")
        print (name + " " + messH + _(u"データ追加中..."))
        #主応力追加
        if ((addFlag[1] == "1") or (addFlag[2] == "1")
            or (addFlag[0] == "1") or (addFlag[6] == "1")):
            lines = pyFistr.addPrincipalStressDataInVtk(lines, addFlag, stressTensor)
        #主ひずみ追加
        if ((addFlag[4] == "1") or (addFlag[5] == "1")
            or (addFlag[3] == "1") or (addFlag[7] == "1")):
            lines = pyFistr.addPrincipalStrainDataInVtk(lines, addFlag, strainTensor)
        #fileに書き出し
        f=open(fileName, "w")
        for line in lines:
            f.write(line)
        f.close()
    if error == "":
        print (messH + _(u"を追加しました。"))
    return error

#
#  addPrincipalStress
#    指定した項目をvtkファイルに追加する。
#    指定項目がvtkファイル内に存在する場合は、その項目は追加しない。
def addPrincipalStress():
    files = glob.glob("convFistrModel.res*.vtk")
    if len(files) == 0:
        error = "noFile"
        return error

    #主応力を追加
    print
    print (_(u"主応力を結果に追加します"))
    steps = []
    nameHeader = ".".join(files[0].split(".")[:-2])
    for fileName in files:
        name = fileName
        step = name.split(".")[-2]
        steps.append(int(step))
    steps.sort()
    names = []
    i = 0
    for fileName in files:
        name = nameHeader+ "." + str(steps[i]) + ".vtk"
        names.append(name)
        i += 1

    error = ""
    for fileName in names:
        name = fileName.split(os.sep)[-1]
        if len(glob.glob(fileName)) == 0:
            error = "noFile"
            break
        #vtkファイル読み込み
        f=open(fileName); lines=f.readlines(); f.close()
        #errorチェック
        #  NodalStressがあるか
        if addFlag[0] == "1" or addFlag[1] == "1" or addFlag[2] == "1" or addFlag[6] == "1":
            if pyFistr.isNodalStressInVtk(lines, stressTensor) == False:
                error = "noStress"
                break
        #  NodalStrainがあるか
        if addFlag[3] == "1" or addFlag[4] == "1" or addFlag[5] == "1" or addFlag[7] == "1":
            if pyFistr.isNodalStrainInVtk(lines, strainTensor) == False:
                error = "noStrain"
                break
        #項目追加
        prStressFlag = pyFistr.isPrincipalStressInVtk(lines)
        prStressVecFlag = pyFistr.isPrincipalStressVecInVtk(lines)
        prStressMisesFlag = pyFistr.isStressMisesInVtk(lines)
        prStressTrescaFlag = pyFistr.isNameInVtk("ndTrescaStress", lines)
        prStrainFlag = pyFistr.isPrincipalStrainInVtk(lines)
        prStrainVecFlag = pyFistr.isPrincipalStrainVecInVtk(lines)
        prStrainMisesFlag = pyFistr.isStrainMisesInVtk(lines)
        prStrainTrescaFlag = pyFistr.isNameInVtk("ndTrescaStrain", lines)

        messH = ""
        if (prStressMisesFlag == False and addFlag[0] == "1"):
            messH += _(u"mises応力 ")
        if ((prStressFlag == False and addFlag[1] == "1")
            or (prStressVecFlag == False and addFlag[2] == "1")):
            messH  += _(u"主応力 ")
        if (prStressTrescaFlag == False and addFlag[6] == "1"):
            messH += _(u"tresca応力 ")
        if (prStrainMisesFlag == False and addFlag[3] == "1"):
            messH += _(u"misesひずみ ")
        if ((prStrainFlag == False and addFlag[4] == "1")
            or (prStrainVecFlag == False and addFlag[5] == "1")):
            messH += _(u"主ひずみ ")
        if (prStrainTrescaFlag == False and addFlag[7] == "1"):
            messH += _(u"trescaひずみ ")
        print (name + " " + messH + _(u"データ追加中..."))
        #主応力追加
        if ((prStressFlag == False and addFlag[1] == "1")
            or (prStressVecFlag == False and addFlag[2] == "1")
            or (prStressMisesFlag == False and addFlag[0] == "1")
            or (prStressTrescaFlag == False and addFlag[6] == "1")):
            lines = pyFistr.addPrincipalStressDataInVtk(lines, addFlag, stressTensor)
        #主ひずみ追加
        if ((prStrainFlag == False and addFlag[4] == "1")
            or (prStrainVecFlag == False and addFlag[5] == "1")
            or (prStrainMisesFlag == False and addFlag[3] == "1")
            or (prStrainTrescaFlag == False and addFlag[7] == "1")):
            lines = pyFistr.addPrincipalStrainDataInVtk(lines, addFlag, strainTensor)
        f=open(fileName, "w")
        for line in lines:
            f.write(line)
        f.close()
    if error == "":
        print (messH + _(u"を追加しました。"))
    return error


if __name__ == "__main__":  
    import gettext
    gettext.install("app") # replace with the appropriate catalog name
    _ = gettext.gettext

    addFlag = [sys.argv[1], sys.argv[2], sys.argv[3],
                sys.argv[4], sys.argv[5], sys.argv[6], sys.argv[7], sys.argv[8]]
    #addFlag の内容
    #  [0]  mises応力
    #  [1]  主応力
    #  [2]  主応力ベクトル
    #  [3]  主ひずみ
    #  [4]  主ひずみベクトル
    #  [5]  tresca応力
    #  [6]  trescaひずみ
    stressTensor = sys.argv[9]
    strainTensor = sys.argv[10]
    #windowApp()  


